==> aliyun-python-sdk-cloudapi-4.3.0.tar.gz: aliyun-python-sdk-cloudapi-4.3.0/aliyunsdkcloudapi/request/v20160714/DeleteTrafficSpecialControlRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class DeleteTrafficSpecialControlRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DeleteTrafficSpecialControl','apigateway')

	def get_TrafficControlId(self):
		return self.get_query_params().get('TrafficControlId')

	def set_TrafficControlId(self,TrafficControlId):
		self.add_query_param('TrafficControlId',TrafficControlId)

	def get_SpecialKey(self):
		return self.get_query_params().get('SpecialKey')

	def set_SpecialKey(self,SpecialKey):
		self.add_query_param('SpecialKey',SpecialKey)

	def get_SpecialType(self):
		return self.get_query_params().get('SpecialType')

	def set_SpecialType(self,SpecialType):
		self.add_query_param('SpecialType',SpecialType)

==> aliyun-python-sdk-cloudapi-4.8.0.tar.gz: aliyun-python-sdk-cloudapi-4.8.0/aliyunsdkcloudapi/request/v20160714/DeleteTrafficSpecialControlRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class DeleteTrafficSpecialControlRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DeleteTrafficSpecialControl','apigateway')

	def get_TrafficControlId(self):
		return self.get_query_params().get('TrafficControlId')

	def set_TrafficControlId(self,TrafficControlId):
		self.add_query_param('TrafficControlId',TrafficControlId)

	def get_SpecialKey(self):
		return self.get_query_params().get('SpecialKey')

	def set_SpecialKey(self,SpecialKey):
		self.add_query_param('SpecialKey',SpecialKey)

	def get_SecurityToken(self):
		return self.get_query_params().get('SecurityToken')

	def set_SecurityToken(self,SecurityToken):
		self.add_query_param('SecurityToken',SecurityToken)

	def get_SpecialType(self):
		return self.get_query_params().get('SpecialType')

	def set_SpecialType(self,SpecialType):
		self.add_query_param('SpecialType',SpecialType)
